@@ -4,6 +4,7 @@
 #
 # This code is part of the Fatiando a Terra project (https://www.fatiando.org)
 #
+# pylint: disable=redefined-outer-name
 """
 Test the core class and factory function.
 """
@@ -30,6 +31,7 @@ from .utils import (
     check_tiny_data,
     check_large_data,
     capture_log,
+    mirror_directory,
 )
 
 # FTP doesn't work on Travis CI so need to be able to skip tests there
@@ -45,6 +47,16 @@ REGISTRY_CORRUPTED = {
 }
 
 
+@pytest.fixture
+def data_dir_mirror(tmp_path):
+    """
+    Mirror the test data folder on a temporary directory. Needed to avoid
+    permission errors when pooch is installed on a non-writable path.
+    """
+    return mirror_directory(DATA_DIR, tmp_path)
+
+
+@pytest.mark.network
 def test_retrieve():
     "Try downloading some data with retrieve"
     with TemporaryDirectory() as local_store:
@@ -70,6 +82,7 @@ def test_retrieve():
             assert log_file.getvalue() == ""
 
 
+@pytest.mark.network
 def test_retrieve_fname():
     "Try downloading some data with retrieve and setting the file name"
     with TemporaryDirectory() as local_store:
@@ -88,6 +101,7 @@ def test_retrieve_fname():
         assert file_hash(fname) == REGISTRY[data_file]
 
 
+@pytest.mark.network
 def test_retrieve_default_path():
     "Try downloading some data with retrieve to the default cache location"
     data_file = "tiny-data.txt"
@@ -111,15 +125,16 @@ def test_retrieve_default_path():
             os.remove(str(expected_location))
 
 
-def test_pooch_local():
+def test_pooch_local(data_dir_mirror):
     "Setup a pooch that already has the local data and test the fetch."
-    pup = Pooch(path=DATA_DIR, base_url="some bogus URL", registry=REGISTRY)
-    true = os.path.join(DATA_DIR, "tiny-data.txt")
+    pup = Pooch(path=data_dir_mirror, base_url="some bogus URL", registry=REGISTRY)
+    true = str(data_dir_mirror / "tiny-data.txt")
     fname = pup.fetch("tiny-data.txt")
     assert true == fname
     check_tiny_data(fname)
 
 
+@pytest.mark.network
 @pytest.mark.parametrize(
     "url", [BASEURL, FIGSHAREURL, ZENODOURL], ids=["https", "figshare", "zenodo"]
 )
@@ -143,6 +158,7 @@ def test_pooch_custom_url(url):
             assert log_file.getvalue() == ""
 
 
+@pytest.mark.network
 @pytest.mark.parametrize(
     "url", [BASEURL, FIGSHAREURL, ZENODOURL], ids=["https", "figshare", "zenodo"]
 )
@@ -185,6 +201,7 @@ class FakeHashMatches:  # pylint: disable=too-few-public-methods
         return hash_matches(*args, **kwargs)
 
 
+@pytest.mark.network
 def test_pooch_download_retry_off_by_default(monkeypatch):
     "Check that retrying the download is off by default"
     with TemporaryDirectory() as local_store:
@@ -215,6 +232,7 @@ class FakeSleep:  # pylint: disable=too-few-public-methods
         self.times.append(secs)
 
 
+@pytest.mark.network
 def test_pooch_download_retry(monkeypatch):
     "Check that retrying the download works if the hash is different"
     with TemporaryDirectory() as local_store:
@@ -247,6 +265,7 @@ def test_pooch_download_retry(monkeypatch):
         assert file_hash(fname) == REGISTRY["tiny-data.txt"]
 
 
+@pytest.mark.network
 def test_pooch_download_retry_fails_eventually(monkeypatch):
     "Check that retrying the download fails after the set amount of retries"
     with TemporaryDirectory() as local_store:
@@ -268,6 +287,7 @@ def test_pooch_download_retry_fails_eventually(monkeypatch):
         assert "does not match the known hash" in str(error)
 
 
+@pytest.mark.network
 def test_pooch_logging_level():
     "Setup a pooch and check that no logging happens when the level is raised"
     with TemporaryDirectory() as local_store:
@@ -282,6 +302,7 @@ def test_pooch_logging_level():
         check_tiny_data(fname)
 
 
+@pytest.mark.network
 def test_pooch_update():
     "Setup a pooch that already has the local data but the file is outdated"
     with TemporaryDirectory() as local_store:
@@ -309,7 +330,8 @@ def test_pooch_update():
             assert log_file.getvalue() == ""
 
 
-def test_pooch_corrupted():
+@pytest.mark.network
+def test_pooch_corrupted(data_dir_mirror):
     "Raise an exception if the file hash doesn't match the registry"
     # Test the case where the file wasn't in the directory
     with TemporaryDirectory() as local_store:
@@ -323,14 +345,14 @@ def test_pooch_corrupted():
             assert logs.split()[0] == "Downloading"
             assert logs.split()[-1] == f"'{path}'."
     # and the case where the file exists but hash doesn't match
-    pup = Pooch(path=DATA_DIR, base_url=BASEURL, registry=REGISTRY_CORRUPTED)
+    pup = Pooch(path=data_dir_mirror, base_url=BASEURL, registry=REGISTRY_CORRUPTED)
     with capture_log() as log_file:
         with pytest.raises(ValueError) as error:
             pup.fetch("tiny-data.txt")
         assert "(tiny-data.txt)" in str(error.value)
         logs = log_file.getvalue()
         assert logs.split()[0] == "Updating"
-        assert logs.split()[-1] == f"'{DATA_DIR}'."
+        assert logs.split()[-1] == f"'{data_dir_mirror}'."
 
 
 def test_pooch_file_not_in_registry():
@@ -392,6 +414,7 @@ def test_pooch_load_registry_invalid_line():
         pup.load_registry(os.path.join(DATA_DIR, "registry-invalid.txt"))
 
 
+@pytest.mark.network
 def test_check_availability():
     "Should correctly check availability of existing and non existing files"
     # Check available remote file
@@ -408,6 +431,7 @@ def test_check_availability():
 
 
 # https://blog.travis-ci.com/2018-07-23-the-tale-of-ftp-at-travis-ci
+@pytest.mark.network
 @pytest.mark.skipif(ON_TRAVIS, reason="FTP is not allowed on Travis CI")
 def test_check_availability_on_ftp():
     "Should correctly check availability of existing and non existing files"
@@ -425,6 +449,7 @@ def test_check_availability_on_ftp():
     assert not pup.is_available("doesnot_exist.zip")
 
 
+@pytest.mark.network
 def test_fetch_with_downloader(capsys):
     "Setup a downloader function for fetch"
 
@@ -455,10 +480,10 @@ def test_fetch_with_downloader(capsys):
             assert log_file.getvalue() == ""
 
 
-def test_invalid_hash_alg():
+def test_invalid_hash_alg(data_dir_mirror):
     "Test an invalid hashing algorithm"
     pup = Pooch(
-        path=DATA_DIR, base_url=BASEURL, registry={"tiny-data.txt": "blah:1234"}
+        path=data_dir_mirror, base_url=BASEURL, registry={"tiny-data.txt": "blah:1234"}
     )
     with pytest.raises(ValueError) as exc:
         pup.fetch("tiny-data.txt")
@@ -466,9 +491,9 @@ def test_invalid_hash_alg():
     assert "'blah'" in str(exc.value)
 
 
-def test_alternative_hashing_algorithms():
+def test_alternative_hashing_algorithms(data_dir_mirror):
     "Test different hashing algorithms using local data"
-    fname = os.path.join(DATA_DIR, "tiny-data.txt")
+    fname = str(data_dir_mirror / "tiny-data.txt")
     check_tiny_data(fname)
     with open(fname, "rb") as fin:
         data = fin.read()
@@ -476,7 +501,7 @@ def test_alternative_hashing_algorithms():
         hasher = hashlib.new(alg)
         hasher.update(data)
         registry = {"tiny-data.txt": f"{alg}:{hasher.hexdigest()}"}
-        pup = Pooch(path=DATA_DIR, base_url="some bogus URL", registry=registry)
+        pup = Pooch(path=data_dir_mirror, base_url="some bogus URL", registry=registry)
         assert fname == pup.fetch("tiny-data.txt")
         check_tiny_data(fname)
 
@@ -502,6 +527,7 @@ def test_download_action():
     assert verb == "Fetching"
 
 
+@pytest.mark.network
 @pytest.mark.parametrize("fname", ["tiny-data.txt", "subdir/tiny-data.txt"])
 def test_stream_download(fname):
     "Check that downloading a file over HTTP works as expected"
